Run the `download-docs` script to populate this directory with official
documentation. Note that the URLS may change, and the script may need to be
updated from time to time.

Normativa: <https://www.fatturapa.gov.it/it/norme-e-regole/normativa/>

Formato: <https://www.fatturapa.gov.it/it/norme-e-regole/documentazione-fattura-elettronica/formato-fatturapa/>

Assocons validator: <https://fatturazione-elettronica-pa.assocons.it/validazione-fattura-elettronica.html>

Agenzia delle Entrate validator: <https://www.fatturapa.gov.it/it/sistemainterscambio/controlli-ed-errori/>

# TODO

Get documentation from <https://www.agenziaentrate.gov.it/wps/content/nsilib/nsi/schede/comunicazioni/fatture+e+corrispettivi/fatture+e+corrispettivi+st/st+invio+di+fatturazione+elettronica>
(it covers Fattura Elettronica Semplificata)
